@@ -36,11 +36,11 @@ def cscal(N, CA, CX, INCX):
     --------
     >>> x = np.array([1+2j, 2+3j, 3+4j], dtype=np.complex64)
     >>> N = len(x)
-    >>> alpha = 5
+    >>> alpha = 5j
     >>> incx = 1
     >>> cscal(N, alpha, x, incx)
-    >>> print(y)
-    [5.+10.j 10.+15.j 15.+20.j]
+    >>> print(x)
+    [-10. +5.j -15.+10.j -20.+15.j]
     """
     if N <= 0:
         return
