@@ -100,21 +100,54 @@ from ..util import slice_
 
 
 def zdrot(N, ZX, INCX, ZY, INCY, C, S):
-    #
-    #  -- Reference BLAS level1 routine (version 3.7.0) --
-    #  -- Reference BLAS is a software package provided by Univ. of Tennessee,    --
-    #  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-    #     December 2016
-    #
-    #     .. Scalar Arguments ..
-    # INTEGER            INCX, INCY, N
-    # DOUBLE PRECISION   C, S
-    #     ..
-    #     .. Array Arguments ..
-    # COMPLEX*16         CX( * ), CY( * )
-    #     ..
-    #
-    # =====================================================================
+    """Applies a Givens rotation to a pair of vectors x and y
+
+    Parameters
+    ----------
+    N : int
+        Number of elements in input vector
+    CX : numpy.ndarray
+        A double precision complex array, dimension (1 + (`N` - 1)*abs(`INCX`))
+    INCX : int
+        Storage spacing between elements of `CX`
+    CY : numpy.ndarray
+        A double precision complex array, dimension (1 + (`N` - 1)*abs(`INCY`))
+    INCY : int
+        Storage spacing between elements of `CY`
+    C : numpy.double
+        The Givens parameter c, with value cos(theta)
+    S : numpy.double
+        The Givens parameter s, with value sin(theta)
+
+    Returns
+    -------
+    None
+
+    See Also
+    --------
+    srot : Single-precision real Givens rotation
+    drot : Double-precision real Givens rotation
+    csrot : Single-precision complex Givens rotation
+
+    Notes
+    -----
+    Online PyBLAS documentation: https://nbviewer.jupyter.org/github/timleslie/pyblas/blob/main/docs/zdrot.ipynb
+    Reference BLAS documentation: https://github.com/Reference-LAPACK/lapack/blob/v3.9.0/BLAS/SRC/zdrot.f
+
+    Examples
+    --------
+    >>> x = np.array([1+2j, 2+3j, 3+4j], dtype=np.complex128)
+    >>> y = np.array([6+7j, 7+8j, 8+9j], dtype=np.complex128)
+    >>> N = len(x)
+    >>> incx = 1
+    >>> incy = 1
+    >>> theta = np.pi/2
+    >>> zdrot(N, x, incx, y, incy, np.cos(theta), np.sin(theta))
+    >>> print(x)
+    [6.+7.j 7.+8.j 8.+9.j]
+    >>> print(y)
+    [-1.-2.j -2.-3.j -3.-4.j]
+    """
     if N <= 0:
         return
     x_slice = slice_(N, INCX)
